-- Solution 1

use AdventureWorks
go
CREATE ASSEMBLY ShowplanXPath 
FROM '<path-to-compiled-DLL>\ShowplanXPath.dll'
go

CREATE PROCEDURE dbo.GetXMLShowplanCost
(
   @tsqlStmt   NVARCHAR(MAX),
   @queryCost   NVARCHAR(MAX) OUT
)
AS EXTERNAL NAME ShowplanXPath.xmlshowplanaccess.GetXMLShowplan
go

DECLARE @query nvarchar(max)   -- the query
DECLARE @cost nvarchar(max)    -- its estimated execution cost

-- set this to your query
set @query = N'select * from person.address'
-- execute the procedure
EXEC dbo.GetXMLShowplanCost @query, @cost OUTPUT
select @cost      -- print the cost

-- note that @cost is nvarchar, we use explicit comparison in case of an error 
-- and implicit conversion for actual cost
if (@cost != '-1') and (@cost <= 0.5)   -- if query is cheap to execute,
  EXEC (@query)         -- execute it; else don't execute
                  -- replace 0.5 with your own threshold
go

--
-- Solution 2

use AdventureWorks
go

CREATE ASSEMBLY ReturnShowplanXML 
FROM '<path-to-compiled-DLL>\ReturnShowplanXML.dll'
go

CREATE PROCEDURE dbo.ReturnXMLShowplan
(
   @tsqlStmt   NVARCHAR(MAX), 
   @retPlanXML   NVARCHAR(MAX) OUT
)
AS EXTERNAL NAME ReturnShowplanXML.xmlshowplanaccess.GetXMLShowplan
go

-- @shplan will contain the showplan in XML format
DECLARE @shplan nvarchar(max)
-- @query will contain the query whose cost is to be estimated
DECLARE @query nvarchar(max)
-- set this to your query
set @query = N'select * from person.address'
EXEC dbo.ReturnXMLShowplan @query, @shplan OUTPUT
DECLARE @querycost float
DECLARE @threshold float
set @threshold = 0.5
-- extract query cost using XQuery
select @querycost = cast(@shplan as xml).value 
('declare namespace p="http://schemas.microsoft.com/sqlserver/2004/07/showplan";
    (//p:RelOp)[1]/@EstimatedTotalSubtreeCost', 'float')
select @querycost
if ( @querycost <= @threshold ) -- if the cost is within limit, 
  EXEC (@query)           -- execute the query; else don't
go