
USE pubs
GO

DROP TABLE audit_table;
GO

CREATE TABLE audit_table (
  id INT IDENTITY PRIMARY KEY,
  trigger_data XML
)
GO

GRANT INSERT ON audit_table TO public
GO

DROP TRIGGER audit_trig
GO

CREATE TRIGGER audit_trig
  ON DATABASE
  FOR DDL_DATABASE_LEVEL_EVENTS
AS
BEGIN
  INSERT INTO audit_table VALUES(EVENTDATA())
END
GO

CREATE TABLE t1 (id INT)
GO

-- query the audit table
SELECT id, trigger_data FROM audit_table;
GO

-- decompose the XML data 
SELECT id, 
 Tab.Col.value('./EventType[1]','nvarchar(50)') AS 'EventType',
 Tab.Col.value('./PostTime[1]','datetime') AS  'PostTime',
 Tab.Col.value('./SPID[1]','nvarchar(50)') AS  'SPID',
 Tab.Col.value('./ServerName[1]','nvarchar(50)') AS  'ServerName',
 Tab.Col.value('./LoginName[1]','nvarchar(50)') AS 'LoginName',
 Tab.Col.value('./UserName[1]','nvarchar(50)') AS 'UserName',
 Tab.Col.value('./DatabaseName[1]','nvarchar(128)') AS 'DatabaseName',
 Tab.Col.value('./SchemaName[1]','nvarchar(128)') AS 'SchemaName',
 Tab.Col.value('./ObjectName[1]','nvarchar(128)') AS 'ObjectName',
 Tab.Col.value('./ObjectType[1]','nvarchar(50)') AS 'ObjectType',
 Tab.Col.value('./TSQLCommand[1]/CommandText[1]','nvarchar(4000)') AS 'CommandText',
 Tab.Col.value('./TSQLCommand[1]/SetOptions[1]/@ANSI_NULLS','nvarchar(3)') AS 'ANSI_NULLS_OPTION',
 Tab.Col.value('./TSQLCommand[1]/SetOptions[1]/@ANSI_NULL_DEFAULT','nvarchar(3)') AS 'ANSI_NULL_DEFAULT_OPTION',
 Tab.Col.value('./TSQLCommand[1]/SetOptions[1]/@ANSI_PADDING','nvarchar(3)') AS 'ANSI_PADDING_OPTION',
 Tab.Col.value('./TSQLCommand[1]/SetOptions[1]/@QUOTED_IDENTIFIER','nvarchar(3)') AS 'QUOTED_IDENTIFIER_OPTION',
 Tab.Col.value('./TSQLCommand[1]/SetOptions[1]/@ENCRYPTED_OPTION','nvarchar(4)') AS 'ENCRYPTED_OPTION'
FROM audit_table
CROSS APPLY
 trigger_data.nodes('/EVENT_INSTANCE') AS Tab(Col)
GO

DROP TRIGGER disallow_by_non_dbo
 ON DATABASE

CREATE TRIGGER disallow_by_non_dbo
  ON DATABASE
  FOR DDL_DATABASE_LEVEL_EVENTS
AS
BEGIN
  IF (EVENTDATA().value('(/EVENT_INSTANCE/UserName)[1]','nvarchar(50)'))
      != N'dbo'
  BEGIN
     PRINT 'Must be DBO to use DDL in this database'
     ROLLBACK
  END
END
GO

CREATE USER user1 FOR LOGIN user1
GO
CREATE SCHEMA u1 AUTHORIZATION user1
GO
GRANT CREATE TABLE TO user1
GO

EXECUTE AS user='user1'
CREATE TABLE u1.u5tab (id int)
GO
REVERT
GO

SELECT * FROM sys.tables